@@ -124,7 +124,7 @@ def retried(
                 try:
                     return function(*args, **kwargs)
                 except Exception as e:
-                    time.sleep(timeout_function(try_number))  # type: ignore
+                    time.sleep(timeout_function(try_number))
                     last_exception = e
 
             raise last_exception
